Bài giảng: Phân khúc Công chúng Truyền thông nội bộ

1. Định nghĩa & vai trò:
Khái niệm “công chúng nội bộ”:
Khái niệm chung (cách hiểu phổ biến và được chấp nhận rộng rãi nhất): Cũng giống như không có định nghĩa chính xác về “công chúng” nói chung, không có khái niệm cố định về thuật ngữ “công chúng nội bộ”.
Các khái niệm đã từng được định nghĩa bởi các học giả nghiên cứu/chuyên gia về công chúng nội bộ:
Grunig, J. E., & Hunt, T. T., 1984: Công chúng nội bộ gồm cả người quản lý lẫn người chịu sự giám sát, quản lý
Men & Bowen, 2017: Công chúng nội bộ bao gồm nhiều nhóm nhân sự cụ thể phụ thuộc vào mô hình từng doanh nghiệp, có mối lo và mối quan tâm khác nhau
Palgrave Macmillan, 2021: Công chúng nội bộ là các nhóm thành viên trong tổ chức nhận thức được các vấn đề của tổ chức và hành động để giải quyết chúng
Hướng dẫn sinh viên thảo luận từng khái niệm, từ đó rút ra kết luận
Khái niệm phân khúc công chúng nội bộ: là phân chia và gom nhóm các thành viên nội bộ cùng chia sẻ các đặc điểm, giá trị tương đồng. 
Tầm quan trọng của việc xác định, phân khúc công chúng nội bộ trong truyền thông nội bộ:
Để thấu hiểu tâm lý, nhu cầu của công chúng mục tiêu
Để lên chiến lược quản trị, phương pháp truyền thông và thông điệp hiệu quả, từ đó gắn kết, tạo động lực để nhân sự làm việc hiệu quả, đóng góp cho tầm nhìn, mục tiêu của tổ chức.
Tránh lãng phí thời gian, nguồn lực, chi phí khi triển khai phương pháp không giải quyết được vấn đề, không đáp ứng đúng nhu cầu của nhân sự.
=> Mục đích: Hướng dẫn nghiên cứu xã hội học nhằm giúp sinh viên hiểu sâu về khái niệm, vai trò cũng như nguồn gốc của chúng, từ đó chủ động nắm bắt kiến thức theo cách tư duy của mỗi cá nhân thay vì bị “ép buộc” theo một chuẩn mực duy nhất.  

2. Khung lý thuyết/mô hình & xu hướng nghiên cứu:
Nội dung các phương pháp phân khúc công chúng nội bộ đã được nghiên cứu và ứng dụng:
Phân khúc theo nhân khẩu học
Phân khúc theo nhận thức, tâm lý và hành vi: mô hình STP (1968) và STOPS (2011)
Hướng dẫn phân tích điểm mạnh, điểm yếu/tính phù hợp của các phương pháp trong ứng dụng thực tiễn
=> Mục đích: giúp sinh viên hiểu được nguồn gốc và cách tiếp cận của các phương pháp đã được nghiên cứu, từ đó có căn cứ lựa chọn phương pháp phù hợp với từng trường hợp ở phần sau.

3. Phương pháp ứng dụng cụ thể & case study (đôi khi có thể kết hợp 3 & 4 dưới dạng phân tích mẫu)
Hướng dẫn phân tích các bước triển khai một mô hình/lý thuyết nghiên cứu trong bối cảnh thực tế (mẫu)
=> Mục đích: giúp sinh viên hiểu cách ứng dụng lý thuyết vào thực tế

4. Phân tích case study trong nước và thế giới:
Thảo luận bối cảnh, phân tích hiệu quả ứng dụng của phương pháp trong các case studies: Không có dữ liệu cụ thể về việc các công ty, tổ chức đang ứng dụng phương pháp (mô hình) phân khúc nào cho nội bộ, hoặc họ chỉ ứng dụng một phần nằm trong mô hình (Tesco - nghiên cứu về attitudes của nhân viên).  
Đề bài phân tích theo tình huống cụ thể cho sinh viên thực hành: Thử ứng dụng các mô hình đã được nghiên cứu trong phân tích để chứng thực hiệu quả.
Feedback theo bài làm (không có trong slides, thường dựa trên kinh nghiệm của giảng viên). Các tiêu chí feedback:
Bài thực hành biết ứng dụng và triển khai phân tích đủ bước theo lý thuyết đã học. VD: Khi phân khúc công chúng vào các nhóm đảm bảo rõ ràng đặc điểm nổi bật của từng nhóm, không trùng lặp theo tiêu chí của mô hình/lý thuyết gốc.
Bài thực hành có nghiên cứu thông tin, insights thực tế theo từng trường hợp cụ thể. VD: Kết hợp với bối cảnh cụ thể để xác định insights/vấn đề của từng nhóm công chúng.
Phương pháp đề xuất trong bài thực hành logic, phù hợp với thực tế và có sự sáng tạo để giải quyết được vấn đề phát hiện ra trong quá trình phân tích.
=> Mục đích: giúp sinh viên đủ khả năng lập tức ứng dụng lý thuyết bài học vào thực hành trong từng tình huống cụ thể, hiểu điểm mạnh, điểm yếu của bản thân để kịp thời rèn luyện, sẵn sàng cho yêu cầu của công việc sau này.

Thông tin lấy từ Sách: Current Trends and Issues in Internal Communication Theory and Practice (New Perspectives in Organizational Communication) (2021, Palgrave Macmillan).pdf
